=======
Credits
=======

* Based on django-usda app from David Sauve (@notanumber)
* United States Department of Agriculture -- Agriculture Research Service.

Development Lead
----------------

* Javi Palanca <jpalanca@codemaniacs.com>

Contributors
------------

None yet. Why not be the first?
